'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CustomFlagIconFactory = undefined;

var _reactCssModules = require('react-css-modules');

var _reactCssModules2 = _interopRequireDefault(_reactCssModules);

var _FlagIcon = require('./FlagIcon');

var _FlagIcon2 = _interopRequireDefault(_FlagIcon);

var _styles = require('../styles');

var _styles2 = _interopRequireDefault(_styles);

var _functions = require('../functions');

var _props = require('../functions/props');

var _propTypes = require('../types/propTypes');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var FlagIconFactory = function FlagIconFactory(React, options) {
  var computedOptions = (0, _functions.makeFlagIconOptions)(options);
  var useCssModules = computedOptions.useCssModules,
      customCodes = computedOptions.customCodes;

  var FlagIconComponent = (0, _FlagIcon2.default)(React, computedOptions);
  FlagIconComponent.displayName = 'FlagIcon';

  if (process.env.NODE_ENV !== 'production') {
    var codes = (0, _props.getCountryCodes)();

    if (customCodes) {
      codes = [].concat(_toConsumableArray(codes), _toConsumableArray(Object.keys(customCodes)));
    }

    FlagIconComponent.propTypes = (0, _propTypes.MakeFlagIconPropsType)(codes);
  }

  if (useCssModules) {
    var computedStyles = (0, _functions.makeStyles)(_styles2.default, options);

    if (process.env.NODE_ENV !== 'production') {
      if (useCssModules) {
        var userSetUseCssModules = options ? options.useCssModules : false;

        if (!Object.prototype.hasOwnProperty.call(computedStyles, 'flag-icon')) {
          var readme = 'https://github.com/matteocng/react-flag-icon-css/blob/master/README.md';
          var readmeModules = 'https://github.com/gajus/react-css-modules#usage';

          console.error('Warning: Detected configuration mismatch/error: [react-flag-icon-css] FlagIconFactory tried to build FlagIcon with the option \'useCssModules\' set to true (' + (userSetUseCssModules ? 'by you' : 'default') + '), but it seems that your environment is not loading the stylesheets in the appropriate way. Two possibilities: \n\n 1. Your project is not using CSS Modules / you don\'t want to use them. Try building FlagIcon like this: \n\n\tFlagIconFactory(React, { useCssModules: false }) \n\n\tSee the README for more info: ' + readme + ' \n\n 2. You are using CSS Modules but your module bundler e.g Webpack is not correctly set up for CSS modules. If you are using Webpack, the key modules to set up are \'style-loader\', \'css-loader\' and \'extract-text-webpack-plugin\' (\'sass-loader\' also comes into play if you are using SASS). The link below may help you:\n\n\t' + readmeModules);
        }
      }
    }

    return (0, _reactCssModules2.default)(FlagIconComponent, computedStyles, {
      allowMultiple: true
    });
  }

  return FlagIconComponent;
};

exports.default = FlagIconFactory;


var CustomFlagIconFactory = function CustomFlagIconFactory(React, options) {
  return FlagIconFactory(React, options);
};
exports.CustomFlagIconFactory = CustomFlagIconFactory;